test

package
v0.0.0-...-a6ba8f7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package test provides utility functions for testing Oar CLI

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddRepoFiles

func AddRepoFiles(repoWorktree *git.Worktree, files []RepoFile) error

func InitGitRepo

func InitGitRepo(path string, files []RepoFile) (*git.Repository, error)

func ReadFile

func ReadFile(path string) (string, error)

func RenderTemplate

func RenderTemplate(data map[string]any) string

func Trim

func Trim(input string) string

Trim trims trailing spaces left by tablewriter on each line to make the lines length-aligned

Types

type RepoFile

type RepoFile struct {
	Path    string
	Content string
}

Jump to