Documentation
¶
Overview ¶
templ: version: v0.3.943
templ: version: v0.3.943
Index ¶
- func ActionButton(action, label, iconName, buttonClass, url string) templ.Component
- func ActionButtonDisabled(action, label, iconName string) templ.Component
- func ActionButtonWithIconClass(action, label, tooltip, iconName, iconClass, buttonClass, url string) templ.Component
- func EmptyState() templ.Component
- func ProjectCard(project ProjectView) templ.Component
- func ProjectGrid(projects []ProjectView, hasProjects bool) templ.Component
- func StatusPill(projectID, status string) templ.Component
- type GitAuthConfig
- type GitHTTPAuthConfig
- type GitSSHAuthConfig
- type ProjectView
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ActionButton ¶
ActionButton renders a clickable action button with icon
func ActionButtonDisabled ¶
ActionButtonDisabled renders a disabled action button
func ActionButtonWithIconClass ¶
func ActionButtonWithIconClass(action, label, tooltip, iconName, iconClass, buttonClass, url string) templ.Component
ActionButtonWithIconClass renders a clickable action button with custom icon styling
func ProjectCard ¶
func ProjectCard(project ProjectView) templ.Component
ProjectCard renders an individual project card with all details and actions
func ProjectGrid ¶
func ProjectGrid(projects []ProjectView, hasProjects bool) templ.Component
ProjectGrid renders the main project grid container
func StatusPill ¶
StatusPill renders the status indicator with unique ID for HTMX updates
Types ¶
type GitAuthConfig ¶
type GitAuthConfig struct {
HTTPAuth *GitHTTPAuthConfig
SSHAuth *GitSSHAuthConfig
}
GitAuthConfig holds Git authentication configuration for a project
type GitHTTPAuthConfig ¶
type GitHTTPAuthConfig struct {
Username string // "token" for GitHub
Password string // actual token/password
}
GitHTTPAuthConfig for HTTP basic authentication (GitHub tokens, etc.)
type GitSSHAuthConfig ¶
type GitSSHAuthConfig struct {
PrivateKey string // PEM-encoded private key as string
User string // SSH user (default: "git")
}
GitSSHAuthConfig for passwordless SSH key authentication
type ProjectView ¶
type ProjectView struct {
ID uuid.UUID
Name string
GitURL string
GitBranch string
GitAuth *GitAuthConfig // Git authentication configuration
Status string // "running", "stopped", "error" (string representation)
LocalCommit *string // Git commit SHA (first 8 chars)
ComposeFiles []string
ComposeOverride *string
Variables []string
AutoDeployEnabled bool
IsOutdated bool // Whether remote has new commits not yet deployed locally
CreatedAt time.Time
UpdatedAt time.Time
}
ProjectView represents the frontend view data for a project (simplified from backend Project)